#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-05-20
#
# metrics plugin for squid checks
#
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    check_metrics,
    metric_info,
    graph_info,
    perfometer_info
)

check_metrics['check_mk-squid'] = {
    'predict_client_requests_per_second': {'auto_graph': False},
    'predict_client_hits_per_second': {'auto_graph': False},
    'predict_server_all_requests': {'auto_graph': False},
    'predict_util': {'auto_graph': False},
    # 'swap_out': {'auto_graph': False},
    # 'swap_in': {'auto_graph': False},
    # 'swap_files_cleaned': {'auto_graph': False},
    # 'maximum_number_of_file_descriptors': {'auto_graph': False},
    # 'available_number_of_file_descriptors': {'auto_graph': False},
    # 'reserved_number_of_file_descriptors': {'auto_graph': False},
}

metric_info['client_hits_per_second'] = {'title': _('Cache hits'), 'unit': '1/s', 'color': '11/a', }
metric_info['client_requests_per_second'] = {'title': _('Requests'), 'unit': '1/s', 'color': '31/a', }
metric_info['client_errors_per_second'] = {'title': _('Errors'), 'unit': '1/s', 'color': '21/a', }

metric_info['predict_client_hits_per_second'] = {'title': _('Cache hits (Predicted)'), 'unit': '1/s', 'color': '52/a', }
metric_info['predict_client_requests_per_second'] = {'title': _('Requests (Predicted)'), 'unit': '1/s',
                                                     'color': '51/a', }

graph_info['squid_client'] = {
    'title': _('Squid Client statistics'),
    'metrics': [
        ('client_hits_per_second', 'line'),
        ('client_errors_per_second', 'line'),
        ('client_requests_per_second', 'line'),
    ],
    'scalars': [
        'client_hits_per_second:warn',
        'client_hits_per_second:crit',
    ],
}

graph_info['squid_client_predicted'] = {
    'title': _('Predicted Squid Client statistics'),
    'metrics': [
        ('predict_client_hits_per_second', '-area'),
        ('predict_client_requests_per_second', 'area'),
    ],
    'optional_metrics': [
        'predict_client_hits_per_second',
        'predict_client_requests_per_second'
    ],
}

metric_info['server_all_requests'] = {'title': _('Requests'), 'unit': '1/s', 'color': '31/a', }
metric_info['server_all_errors'] = {'title': _('Errors'), 'unit': '1/s', 'color': '21/a', }

metric_info['predict_server_all_requests'] = {'title': _('Requests (Predicted)'), 'unit': '1/s', 'color': '51/a', }

graph_info['squid_server'] = {
    'title': _('Squid Server statistics'),
    'metrics': [
        ('server_all_errors', 'line'),
        ('server_all_requests', 'line'),

    ],
    'scalars': [
        'server_all_requests:warn',
        'server_all_requests:crit',
    ],
}

graph_info['squid_server_predicted'] = {
    'title': _('Predicted Squid Server statistics'),
    'metrics': [
        ('predict_server_all_requests', 'area'),
    ],
}

metric_info['cpu_time'] = {'title': _('CPU time'), 'unit': 's', 'color': '16/a', }
metric_info['predict_util'] = {'title': _('CPU utilization (Predicted)'), 'unit': 's', 'color': '51/a', }

graph_info['squid_cpu_time'] = {
    'title': _('Squid CPU time'),
    'metrics': [
        ('cpu_time', 'area'),
    ],
    'scalars': [
        'cpu_time:warn',
        'cpu_time:crit',
    ],
}

graph_info['squid_cpu_util_predicted'] = {
    'title': _('Predicted Squid CPU utilization'),
    'metrics': [
        ('predict_util', 'area'),
    ],
}

metric_info['dns_median_svc_time'] = {'title': _('DNS response time'), 'unit': 's', 'color': '26/a', }

graph_info['squid_dns_median_svc_time'] = {
    'title': _('Squid DNS median response time'),
    'metrics': [
        ('dns_median_svc_time', 'area'),
    ],
    'scalars': [
        'dns_median_svc_time:warn',
        'dns_median_svc_time:crit',
    ],
}

perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'dns_median_svc_time',
    'half_value': 2,
    'exponent': 2,
})


metric_info['swap_out'] = {'title': _('Out'), 'unit': '1/s', 'color': '26/a', }
metric_info['swap_in'] = {'title': _('In'), 'unit': '1/s', 'color': '26/b', }
metric_info['swap_files_cleaned'] = {'title': _('Files cleaned'), 'unit': '1/s', 'color': '26/b', }

graph_info['squid_swap'] = {
    'title': _('Squid Swap'),
    'metrics': [
        ('swap_out', 'line'),
        ('swap_in', 'line'),
        ('swap_files_cleaned', 'line'),
    ],
    # 'scalars': [
    #     'swap_files_cleaned:warn',
    #     'swap_files_cleaned:crit',
    # ],
}

metric_info['maximum_number_of_file_descriptors'] = {'title': _('Maximum'), 'unit': 'count', 'color': '31/a', }
metric_info['available_number_of_file_descriptors'] = {'title': _('Available'), 'unit': 'count', 'color': '26/a', }
metric_info['reserved_number_of_file_descriptors'] = {'title': _('Reserved'), 'unit': 'count', 'color': '14/a', }

graph_info['squid_file_descriptors'] = {
    'title': _('Squid File Descriptors'),
    'metrics': [
        ('maximum_number_of_file_descriptors', 'line'),
        ('available_number_of_file_descriptors', 'line'),
        ('reserved_number_of_file_descriptors', 'line'),
    ],
    'scalars': [
        'available_number_of_file_descriptors:warn',
        'available_number_of_file_descriptors:crit',
    ],
}

perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'available_number_of_file_descriptors',
    'half_value': 1000,
    'exponent': 2,
})